def bye():
    print("Bye")
